@@ -1,4 +1,5 @@
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE CPP #-}
 -- | The Github Repos API, as documented at
 -- <http://developer.github.com/v3/repos/>
 module Github.Repos (
@@ -245,7 +246,11 @@ deleteRepo auth owner repo = do
                 -- non-existent repository
              then return (Left (HTTPConnectionError
                                 (E.toException
-                                 (StatusCodeException status headers))))
+                                 (StatusCodeException status headers
+#if MIN_VERSION_http_conduit(1, 9, 0)
+                                 (responseCookieJar resp)
+#endif
+                                 ))))
              else return (Right ())
   where
     url = "https://api.github.com/repos/" ++ owner ++ "/" ++ repo
